| Title: | Statistical Deadband Algorithms Comparison |
|---|---|
| Description: | Statistical deadband algorithms are based on the Send-On-Delta concept as in Miskowicz(2006,<doi:10.3390/s6010049>). A collection of functions compare effectiveness and fidelity of sampled signals using statistical deadband algorithms. |
| Authors: | Nunzio Torrisi |
| Maintainer: | Nunzio Torrisi <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-06-05 08:06:56 UTC |
| Source: | https://github.com/cran/deadband |
This function allows you to compute the Absolute Deadband(AD) algorithm
deadbandAD(x, EUmax, EUmin, d, offset)deadbandAD(x, EUmax, EUmin, d, offset)
x |
The vector of the samples before the deadband algorithm |
EUmax |
The Engineering Unit higher bound |
EUmin |
The Engineering Unit lower bound |
d |
Deadband percent parameter in range 0..1 |
offset |
How many sample do you want skip at begin? Defaults is n=20 |
A list containing the L2 distance and the Number of filtered samples
deadbandAD(rnorm(40, mean = 0, sd = 1),+0.5,-0.5,0.01,20)deadbandAD(rnorm(40, mean = 0, sd = 1),+0.5,-0.5,0.01,20)
This function allows you to compute the Bollinger Deadband(BD) algorithm
deadbandBD(x, d, offset, k)deadbandBD(x, d, offset, k)
x |
The vector of the samples before the deadband algorithm |
d |
Deadband percent parameter in range 0..1 |
offset |
How many sample do you want skip at begin? Defaults is n=20 |
k |
multiplier used in Bollinger theory |
A list containing the L2 distance and the Number of filtered samples
deadbandBD(rnorm(40, mean = 0, sd = 1),0.01,20,2)deadbandBD(rnorm(40, mean = 0, sd = 1),0.01,20,2)
This function allows you to compute the Volatility Deadband(VD) algorithm
deadbandVD(x, d, offset, k)deadbandVD(x, d, offset, k)
x |
The vector of the samples before the deadband algorithm |
d |
Deadband percent parameter in range 0..1 |
offset |
How many sample do you want skip at begin? Defaults is n=20 |
k |
multiplier used in Bollinger theory |
A list containing the L2 distance and the Number of filtered samples
deadbandVD(rnorm(40, mean = 0, sd = 1),0.01,20,2)deadbandVD(rnorm(40, mean = 0, sd = 1),0.01,20,2)
Sampling rate: 210ms for synthetic.sub35;
synthetic.sub35synthetic.sub35
A data table with a column for each signal:
The original dataset containing the 10 pseudo periodoc signal are available for download at: http://archive.ics.uci.edu/ml/machine-learning-databases/synthetic-mld/synthetic.data.gz More Info at: http://archive.ics.uci.edu/ml/machine-learning-databases/synthetic-mld/synthetic.data.html
Dataset freely available for research use.
Sampling rate: 240ms for synthetic.sub40;
synthetic.sub40synthetic.sub40
A data table with a column for each signal:
The original dataset containing the 10 pseudo periodoc signal are available for download at: http://archive.ics.uci.edu/ml/machine-learning-databases/synthetic-mld/synthetic.data.gz More Info at: http://archive.ics.uci.edu/ml/machine-learning-databases/synthetic-mld/synthetic.data.html
Dataset freely available for research use.
Sampling rate: 252ms for synthetic.sub42; The original dataset containing the 10 pseudo periodoc signal are available for download at: http://archive.ics.uci.edu/ml/machine-learning-databases/synthetic-mld/synthetic.data.gz More Info at: http://archive.ics.uci.edu/ml/machine-learning-databases/synthetic-mld/synthetic.data.html
synthetic.sub42synthetic.sub42
A data table with a column for each signal:
Dataset freely available for research use.
Sampling rate: 300ms for synthetic.sub50;
synthetic.sub50synthetic.sub50
A data table with a column for each signal:
The original dataset containing the 10 pseudo periodoc signal are available for download at: http://archive.ics.uci.edu/ml/machine-learning-databases/synthetic-mld/synthetic.data.gz More Info at: http://archive.ics.uci.edu/ml/machine-learning-databases/synthetic-mld/synthetic.data.html
Dataset freely available for research use.